==> feathers-mongoose-casl-dashboard-1.2.2.tgz: package/es/RefComponent.js <==
function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React, { Component } from 'react';
import { fields } from 'redux-admin'; //  ''redux-admin'';
import Dashboard from './DashboardApp.js';
import { Modal, Tag, Icon, Form } from 'antd';
import isEmpty from 'lodash/isEmpty';
import { NetProvider } from 'net-provider'; // 'src/components/net-provider';
import { LOCALS } from './local';

var Consumer = fields.Consumer;

var getValue = function getValue(props) {
  return props.multiSelect ? props.value || [] : props.value ? [props.value] : [];
};

var RefComponent = function (_Component) {
  _inherits(RefComponent, _Component);

  function RefComponent(props) {
    _classCallCheck(this, RefComponent);

    var _this = _possibleConstructorReturn(this, _Component.call(this, props));

    _this.showModal = function () {
      _this.setState({
        visible: true,
        selectedRowKeys: getValue(_this.props)
      });
    };

    _this.handleOk = function (e) {
      _this.props.setFieldValue(_this.props.fieldName, _this.props.multiSelect ? _this.state.selectedRowKeys : _this.state.selectedRowKeys[0]);
      _this.setState({
        visible: false
      });
    };

    _this.handleCancel = function (e) {
      _this.setState({
        visible: false,
        selectedRowKeys: getValue(_this.props)
      });
    };

    _this.removeItem = function (val) {
      var value = getValue(_this.props);
      _this.props.setFieldValue(_this.props.fieldName, _this.props.multiSelect ? value.filter(function (item) {
        return item !== val;
      }) : null);
    };

    _this.renderItem = function (item, _disabled) {
      var _this$props = _this.props,
          optionKey = _this$props.optionKey,
          optionLabel = _this$props.optionLabel,
          multiSelect = _this$props.multiSelect,
          disabled = _this$props.disabled;

      var isString = typeof item === 'string';
      var val = isString ? item : item[optionKey];
      var render = function render(d) {
        return React.createElement(
          Tag,
          {
            className: multiSelect ? 'ra-refModal__multiTag ra-text-ellipsis' : 'ra-refModal__oneTag ra-text-ellipsis',
            key: val,
            closable: !disabled || !_disabled,
            onClose: function onClose() {
              return _this.removeItem(val);
            } },
          React.createElement(
            'a',
            { href: '/app/dashboard?screen=' + _this.props.url + '&e=' + (isString ? item : item._id), target: '_blank' },
            d
          )
        );
      };
      // item is object
      if (!isString) {
        return render(item[optionLabel] || item[optionKey]);
      }
      // item is String
      if (optionLabel) {
        var fullObject = _this.state.selectedRowKeysData.find(function (obj) {
          return obj[optionKey] === item;
        });
        if (fullObject) return render(fullObject[optionLabel] || item);
        return React.createElement(
          NetProvider,
          {
            loadData: {
              url: _this.props.url + '/' + item,
              targetKey: 'ref-displayKey-' + _this.props.url + '/' + item,
              customHandleResponse: function customHandleResponse(res) {
                return res.data;
              },
              onEnd: function onEnd(_ref) {
                var data = _ref.data;

                var selectedRowKeysData = [].concat(_this.state.selectedRowKeysData, [data]);
                _this.setState({ selectedRowKeysData: selectedRowKeysData });
              }
            }
          },
          function (_ref2) {
            var data = _ref2.data;

            fullObject = data || {};
            return render(fullObject[optionLabel] || item);
          }
        );
      } else {
        return render(item);
      }
    };

    _this.renderValue = function () {
      var _this$props2 = _this.props,
          value = _this$props2.value,
          multiSelect = _this$props2.multiSelect,
          disabled = _this$props2.disabled;

      var _isEmpty = isEmpty(value);
      var showPanIcon = !multiSelect && !_isEmpty;
      return React.createElement(
        'div',
        { className: 'ra-refModal__input ' + (_isEmpty ? ' --empty' : '') + ' ' + (disabled ? ' --disabled' : ''), onClick: _isEmpty && _this.showModal },
        _isEmpty ? _this.renderEmpty() : multiSelect ? value.map(function (item) {
          return _this.renderItem(item, disabled);
        }) : _this.renderItem(value, disabled),
        !disabled && React.createElement(Icon, { className: 'ra-refModal__input__plus', type: showPanIcon ? "edit" : "plus-square", onClick: _this.showModal })
      );
    };

    _this.renderEmpty = function () {
      return _this.props.multiSelect ? 'Click to select many' : 'Click to select one';
    };

    _this.onSelect = function (record) {
      var selectedRowKeys = [].concat(_this.state.selectedRowKeys);
      var selectedRowKeysData = [].concat(_this.state.selectedRowKeysData, [record]);
      var isSelected = selectedRowKeys.find(function (item) {
        return item === record._id;
      });
      if (isSelected) {
        selectedRowKeys = selectedRowKeys.filter(function (item) {
          return item !== record._id;
        });
      } else {
        selectedRowKeysData.push(record);
        selectedRowKeys.push(record._id);
      }
      if (_this.props.multiSelect) {
        _this.setState({ selectedRowKeys: selectedRowKeys, selectedRowKeysData: selectedRowKeysData });
      } else {
        if (isSelected) _this.setState({ selectedRowKeys: [], selectedRowKeysData: selectedRowKeysData });
        if (!isSelected) _this.setState({ selectedRowKeys: [record._id], selectedRowKeysData: selectedRowKeysData });
      }
    };

    _this.state = {
      visible: false,
      selectedRowKeys: getValue(_this.props),
      selectedRowKeysData: []
    };
    return _this;
  }

  RefComponent.prototype.render = function render() {
    var _this2 = this;

    var selectedRowKeys = this.state.selectedRowKeys;
    var _props = this.props,
        url = _props.url,
        multiSelect = _props.multiSelect,
        fieldName = _props.fieldName,
        label = _props.label,
        fieldError = _props.fieldError,
        required = _props.required;

    var selectRowCounter = ' - (' + selectedRowKeys.length + ')';
    return React.createElement(
      Form.Item,
      { label: label, className: 'ra-docFieldWrapper ra-docField-' + fieldName, required: required, hasFeedback: fieldError, help: fieldError, validateStatus: fieldError ? 'error' : 'validating' },
      this.renderValue(),
      React.createElement(
        Modal,
        {
          title: LOCALS.RENDER_SELECT_MODAL_TITLE(fieldName, selectRowCounter),
          destroyOnClose: true,
          visible: this.state.visible,
          onOk: this.handleOk,
          onCancel: this.handleCancel,
          width: 'calc(100% - 20px)',
          style: { top: 10 },
          className: 'ra-refModal',
          closable: false,
          okText: LOCALS.SELECT
        },
        React.createElement(Dashboard, {
          listTargetKeyPrefix: 'RefComponent',
          selectMode: true,
          url: url
          // onSelect={value => setFieldValue(name, value)}
          , showBreadcrumb: false,
          syncWithUrl: false,
          rowSelection: {
            selectedRowKeys: this.state.selectedRowKeys,
            onSelect: function onSelect(row, record, rows) {
              return _this2.onSelect(row);
            },
            type: multiSelect ? 'checkbox' : 'radio'
          },
          onRow: function onRow(record) {
            return {
              onClick: function onClick() {
                return _this2.onSelect(record);
              }
            };
          },
          editAfterSaved: false
        })
      )
    );
  };

  return RefComponent;
}(Component);

var RefComponentWithValue = function (_React$Component) {
  _inherits(RefComponentWithValue, _React$Component);

  function RefComponentWithValue() {
    _classCallCheck(this, RefComponentWithValue);

    return _possibleConstructorReturn(this, _React$Component.apply(this, arguments));
  }

  RefComponentWithValue.prototype.render = function render() {
    var _this4 = this;

    var _props$fieldProps = this.props.fieldProps,
        name = _props$fieldProps.name,
        multiSelect = _props$fieldProps.multiSelect,
        optionKey = _props$fieldProps.optionKey,
        optionLabel = _props$fieldProps.optionLabel,
        label = _props$fieldProps.label,
        required = _props$fieldProps.required,
        disabled = _props$fieldProps.disabled;

    return React.createElement(
      Consumer,
      null,
      function (form) {
        var setFieldValue = form.setFieldValue,
            values = form.values,
            errors = form.errors;

        var value = fields.util.getFieldValueByName(name, values);
        var fieldError = fields.util.getFieldErrorByName(name, errors);
        return React.createElement(RefComponent, { disabled: disabled, fieldError: fieldError, required: required, label: label, optionKey: optionKey, optionLabel: optionLabel, url: _this4.props.url, value: value, setFieldValue: setFieldValue, fieldName: name, multiSelect: multiSelect });
      }
    );
  };

  return RefComponentWithValue;
}(React.Component);

export default RefComponentWithValue;

==> feathers-mongoose-casl-dashboard-1.3.3.tgz: package/es/RefComponent.js <==
function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React, { Component } from 'react';
import { fields } from 'redux-admin';
import { Modal, Tag, Icon, Form } from 'antd';
import isEmpty from 'lodash/isEmpty';
import { NetProvider } from 'net-provider';
import Dashboard from './DashboardApp.js';
import { LOCALS } from './local';

var Consumer = fields.Consumer;


var getValue = function getValue(props) {
  return props.multiSelect ? props.value || [] : props.value ? [props.value] : [];
};

var RefComponent = function (_Component) {
  _inherits(RefComponent, _Component);

  function RefComponent(props) {
    _classCallCheck(this, RefComponent);

    var _this = _possibleConstructorReturn(this, _Component.call(this, props));

    _this.showModal = function () {
      _this.setState({
        visible: true,
        selectedRowKeys: getValue(_this.props)
      });
    };

    _this.handleOk = function (e) {
      _this.props.setFieldValue(_this.props.fieldName, _this.props.multiSelect ? _this.state.selectedRowKeys : _this.state.selectedRowKeys[0]);
      _this.setState({
        visible: false
      });
    };

    _this.handleCancel = function (e) {
      _this.setState({
        visible: false,
        selectedRowKeys: getValue(_this.props)
      });
    };

    _this.removeItem = function (val) {
      var value = getValue(_this.props);
      _this.props.setFieldValue(_this.props.fieldName, _this.props.multiSelect ? value.filter(function (item) {
        return item !== val;
      }) : null);
    };

    _this.renderItem = function (item, _disabled) {
      var _this$props = _this.props,
          optionKey = _this$props.optionKey,
          optionLabel = _this$props.optionLabel,
          multiSelect = _this$props.multiSelect,
          disabled = _this$props.disabled;

      var isString = typeof item === 'string';
      var val = isString ? item : item[optionKey];
      var render = function render(d) {
        return React.createElement(
          Tag,
          {
            className: multiSelect ? 'ra-refModal__multiTag ra-text-ellipsis' : 'ra-refModal__oneTag ra-text-ellipsis',
            key: val,
            closable: !disabled || !_disabled,
            onClose: function onClose() {
              return _this.removeItem(val);
            }
          },
          React.createElement(
            'a',
            { href: '/app/dashboard?screen=' + _this.props.url + '&e=' + (isString ? item : item._id), target: '_blank' },
            d
          )
        );
      };
      // item is object
      if (!isString) {
        return render(item[optionLabel] || item[optionKey]);
      }
      // item is String
      if (optionLabel) {
        var fullObject = _this.state.selectedRowKeysData.find(function (obj) {
          return obj[optionKey] === item;
        });
        if (fullObject) return render(fullObject[optionLabel] || item);
        return React.createElement(
          NetProvider,
          {
            loadData: {
              url: _this.props.url + '/' + item,
              targetKey: 'ref-displayKey-' + _this.props.url + '/' + item,
              customHandleResponse: function customHandleResponse(res) {
                return res.data;
              },
              onEnd: function onEnd(_ref) {
                var data = _ref.data;

                var selectedRowKeysData = [].concat(_this.state.selectedRowKeysData, [data]);
                _this.setState({ selectedRowKeysData: selectedRowKeysData });
              }
            }
          },
          function (_ref2) {
            var data = _ref2.data;

            fullObject = data || {};
            return render(fullObject[optionLabel] || item);
          }
        );
      }
      return render(item);
    };

    _this.renderValue = function () {
      var _this$props2 = _this.props,
          value = _this$props2.value,
          multiSelect = _this$props2.multiSelect,
          disabled = _this$props2.disabled;

      var _isEmpty = isEmpty(value);
      var showPanIcon = !multiSelect && !_isEmpty;
      return React.createElement(
        'div',
        { className: 'ra-refModal__input ' + (_isEmpty ? ' --empty' : '') + ' ' + (disabled ? ' --disabled' : ''), onClick: _isEmpty && _this.showModal },
        _isEmpty ? _this.renderEmpty() : multiSelect ? value.map(function (item) {
          return _this.renderItem(item, disabled);
        }) : _this.renderItem(value, disabled),
        !disabled && React.createElement(Icon, { className: 'ra-refModal__input__plus', type: showPanIcon ? 'edit' : 'plus-square', onClick: _this.showModal })
      );
    };

    _this.renderEmpty = function () {
      return _this.props.multiSelect ? 'Click to select many' : 'Click to select one';
    };

    _this.onSelect = function (record) {
      var selectedRowKeys = [].concat(_this.state.selectedRowKeys);
      var selectedRowKeysData = [].concat(_this.state.selectedRowKeysData, [record]);
      var isSelected = selectedRowKeys.find(function (item) {
        return item === record._id;
      });
      if (isSelected) {
        selectedRowKeys = selectedRowKeys.filter(function (item) {
          return item !== record._id;
        });
      } else {
        selectedRowKeysData.push(record);
        selectedRowKeys.push(record._id);
      }
      if (_this.props.multiSelect) {
        _this.setState({ selectedRowKeys: selectedRowKeys, selectedRowKeysData: selectedRowKeysData });
      } else {
        if (isSelected) _this.setState({ selectedRowKeys: [], selectedRowKeysData: selectedRowKeysData });
        if (!isSelected) _this.setState({ selectedRowKeys: [record._id], selectedRowKeysData: selectedRowKeysData });
      }
    };

    _this.state = {
      visible: false,
      selectedRowKeys: getValue(_this.props),
      selectedRowKeysData: []
    };
    return _this;
  }

  RefComponent.prototype.render = function render() {
    var _this2 = this;

    var selectedRowKeys = this.state.selectedRowKeys;
    var _props = this.props,
        url = _props.url,
        multiSelect = _props.multiSelect,
        fieldName = _props.fieldName,
        label = _props.label,
        fieldError = _props.fieldError,
        required = _props.required;

    var selectRowCounter = ' - (' + selectedRowKeys.length + ')';
    return React.createElement(
      Form.Item,
      { label: label, className: 'ra-docFieldWrapper ra-docField-' + fieldName, required: required, hasFeedback: fieldError, help: fieldError, validateStatus: fieldError ? 'error' : 'validating' },
      this.renderValue(),
      React.createElement(
        Modal,
        {
          title: LOCALS.RENDER_SELECT_MODAL_TITLE(fieldName, selectRowCounter),
          destroyOnClose: true,
          visible: this.state.visible,
          onOk: this.handleOk,
          onCancel: this.handleCancel,
          width: 'calc(100% - 20px)',
          style: { top: 10 },
          className: 'ra-refModal',
          closable: false,
          okText: LOCALS.SELECT
        },
        React.createElement(Dashboard, {
          listTargetKeyPrefix: 'RefComponent',
          selectMode: true,
          url: url
          // onSelect={value => setFieldValue(name, value)}
          , showBreadcrumb: false,
          syncWithUrl: false,
          rowSelection: {
            selectedRowKeys: this.state.selectedRowKeys,
            onSelect: function onSelect(row, record, rows) {
              return _this2.onSelect(row);
            },
            type: multiSelect ? 'checkbox' : 'radio'
          },
          onRow: function onRow(record) {
            return {
              onClick: function onClick() {
                return _this2.onSelect(record);
              }
            };
          },
          editAfterSaved: false
        })
      )
    );
  };

  return RefComponent;
}(Component);

var RefComponentWithValue = function (_React$Component) {
  _inherits(RefComponentWithValue, _React$Component);

  function RefComponentWithValue() {
    _classCallCheck(this, RefComponentWithValue);

    return _possibleConstructorReturn(this, _React$Component.apply(this, arguments));
  }

  RefComponentWithValue.prototype.render = function render() {
    var _this4 = this;

    var _props$fieldProps = this.props.fieldProps,
        name = _props$fieldProps.name,
        multiSelect = _props$fieldProps.multiSelect,
        optionKey = _props$fieldProps.optionKey,
        optionLabel = _props$fieldProps.optionLabel,
        label = _props$fieldProps.label,
        required = _props$fieldProps.required,
        disabled = _props$fieldProps.disabled;

    return React.createElement(
      Consumer,
      null,
      function (form) {
        var setFieldValue = form.setFieldValue,
            values = form.values,
            errors = form.errors;

        var value = fields.util.getFieldValueByName(name, values);
        var fieldError = fields.util.getFieldErrorByName(name, errors);
        return React.createElement(RefComponent, { disabled: disabled, fieldError: fieldError, required: required, label: label, optionKey: optionKey, optionLabel: optionLabel, url: _this4.props.url, value: value, setFieldValue: setFieldValue, fieldName: name, multiSelect: multiSelect });
      }
    );
  };

  return RefComponentWithValue;
}(React.Component);

export default RefComponentWithValue;
